4.31. umbra.managers.fileSystemEventsManager — Umbra 1.0.9 documentation

# 4.31. umbra.managers.fileSystemEventsManager

fileSystemEventsManager.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `FileSystemEventsManager` class.

Others:

## 4.31.1. Module Attributes

`umbra.managers.fileSystemEventsManager.` `LOGGER`

## 4.31.2. Classes

class `umbra.managers.fileSystemEventsManager.` `FileSystemEventsManager`(parent=None)

  Bases: `PyQt4.QtCore.QThread`

  Defines the file system events manager.

  Initializes the class.

  `fileChanged`

    This signal is emited by the `FileSystemEventsManager` class when a file is changed. ( pyqtSignal )

    Returns: | Current changed file.
    Return type: | unicode

  `fileInvalidated`

    This signal is emited by the `FileSystemEventsManager` class when a file is invalidated. ( pyqtSignal )

    Returns: | Current invalidated file.
    Return type: | unicode

  `directoryChanged`

    This signal is emited by the `FileSystemEventsManager` class when a directory is changed. ( pyqtSignal )

    Returns: | Current changed directory.
    Return type: | unicode

  `directoryInvalidated`

    This signal is emited by the `FileSystemEventsManager` class when a directory is invalidated. ( pyqtSignal )

    Returns: | Current invalidated directory.
    Return type: | unicode

  `container`

    Property for self.__container attribute.

    Returns: | self.__container.
    Return type: | QObject

  `paths`

    Property for self.__paths attribute.

    Returns: | self.__paths.
    Return type: | dict

  `timer`

    Property for self.__timer attribute.

    Returns: | self.__timer.
    Return type: | QTimer

  `timerCycleMultiplier`

    Property for self.__timerCycleMultiplier attribute.

    Returns: | self.__timerCycleMultiplier.
    Return type: | float

  `get`(path, default=None)

    Returns given path value.

    Parameters: | path (unicode) – Path name. default (object) – Default value if path is not found.
    Returns: | Action.
    Return type: | QAction

  `run`()

    Reimplements the `QThread.run()` method.

  `listPaths`()

    Returns the registered paths.

    Returns: | Registered paths.
    Return type: | list

  `isPathRegistered`(path)

    Returns if the given path is registered.

    Parameters: | path (unicode) – Path name.
    Returns: | Is path registered.
    Return type: | bool

  `registerPath`(path, modifiedTime=None)

    Registers given path.

    Parameters: | path (unicode) – Path name. modifiedTime (int or float) – Custom modified time.
    Returns: | Method success.
    Return type: | bool

  `unregisterPath`(path)

    Unregisters given path.

    Parameters: | path (unicode) – Path name.
    Returns: | Method success.
    Return type: | bool

  `getPathModifiedTime`(path)

    Returns given path modification time.

    Parameters: | path (unicode) – Path.
    Returns: | Modification time.
    Return type: | int